package com.uas.search.constant;

/**
 * 索引相关的常量
 * 
 * @author suntg
 * @since 2016年8月3日下午1:54:14
 */
public class SearchConstants {

	/**
	 * 用来对搜索结果进行排序，该键代表排序的排序方式
	 */
	public static final String SORT_KEY = "sort";

	/**
	 * 单据搜索时，若限定时间范围，可以键值对的形式传递参数，该键代表开始时间
	 */
	public static final String FROM_DATE_KEY = "fromDate";

	/**
	 * 单据搜索时，若限定时间范围，可以键值对的形式传递参数，该键代表截止时间
	 */
	public static final String END_DATE_KEY = "endDate";

	/**
	 * 默认搜索的最大的记录条数
	 */
	public static final int TOP_NUM = 1024 * 1024 * 1024;

	/**
	 * 标准器件类索引任务（包含类目(kind)、品牌(brand)、器件(component)）
	 */
	public static final String STANDARD_INDEX_TASK = "standard_index_task";

	/**
	 * 在售商品类索引任务（包含goods，pcb_goods）
	 */
	public static final String GOODS_INDEX_TASK = "goods_index_task";

	/**
	 * 物料索引任务（包含v$product$private）
	 */
	public static final String PRODUCTS_INDEX_TASK = "products_index_task";

	/**
	 * 订单类索引任务（包含orders,purchases,invoice_fmor,invoice_fmpu）
	 */
	public static final String ORDERS_INDEX_TASK = "orders_index_task";

	/**
	 * 类目表名
	 */
	public static final String KIND_TABLE_NAME = "product$kind";

	/**
	 * 类目
	 */
	public static final String KIND = "kind";

	/**
	 * 品牌表名
	 */
	public static final String BRAND_TABLE_NAME = "product$brand";

	/**
	 * 品牌
	 */
	public static final String BRAND = "brand";

	/**
	 * 器件表名
	 */
	public static final String COMPONENT_TABLE_NAME = "product$component";

	/**
	 * 批次器件视图表名（不必真实存在）
	 */
	public static final String GOODS_TABLE_NAME = "v$product$cmpgoods";

	/**
	 * 批次表
	 */
	public static final String TRADE_GOODS_TABLE_NAME = "trade$goods";

    /**
     * PCB 表名
     */
    public static final String PCB_TABLE_NAME = "product$pcb";

    /**
     * PCB 批次表名（不必真实存在）
     */
    public static final String PCB_GOODS_TABLE_NAME = "pcb_goods";

	/**
	 * 商城销售订单表名
	 */
	public static final String ORDER_TABLE_NAME = "trade$order";

	/**
	 * 商城销售订单的发货单表名
	 */
	public static final String ORDER_INVOICE_TABLE_NAME = "trade$invoice_fmor";

	/**
	 * 商城采购订单表名
	 */
	public static final String PURCHASE_TABLE_NAME = "trade$purchase";

	/**
	 * 商城采购订单的发货单表名
	 */
	public static final String PURCHASE_INVOICE_TABLE_NAME = "trade$invoice_fmpu";

	/**
	 * 物料表
	 */
	public static final String PRODUCTS_PRIVATE_TABLE_NAME = "v$product$private";
	/**
	 * 个人物料表
	 */
	public static final String PRODUCTS_USERS_TABLE_NAME = "product$users";


	// 类目索引字段的key
	public static final String KIND_ID_FIELD = "ki_id";
	public static final String KIND_NAMECN_FIELD = "ki_name_cn";
    public static final String KIND_NAMECN_UNTOKENIZED_FIELD = "ki_name_cn_untokenized";
	public static final String KIND_LEVEL_FIELD = "ki_level";
	public static final String KIND_ISLEAF_FIELD = "ki_isleaf";
    public static final String KIND_VISIT_COUNT_FIELD = "ki_visit_count";
    public static final String KIND_SEARCH_COUNT_FIELD = "ki_search_count";

	// 品牌索引字段的key
	public static final String BRAND_ID_FIELD = "br_id";
	public static final String BRAND_NAMECN_FIELD = "br_name_cn";
	public static final String BRAND_NAMEEN_FIELD = "br_name_en";
    public static final String BRAND_NAMECN_UNTOKENIZED_FIELD = "br_name_cn_untokenized";
    public static final String BRAND_NAMEEN_UNTOKENIZED_FIELD = "br_name_en_untokenized";
	public static final String BRAND_UUID_FIELD = "br_uuid";
    public static final String BRAND_VISIT_COUNT_FIELD = "br_visit_count";
    public static final String BRAND_SEARCH_COUNT_FIELD = "br_search_count";
    public static final String BRAND_WEIGHT_FIELD = "br_weight";

	// 器件索引字段的key
	public static final String COMPONENT_ID_FIELD = "cmp_id";
	public static final String COMPONENT_UUID_FIELD = "cmp_uuid";
	public static final String COMPONENT_CODE_FIELD = "cmp_code";
    public static final String COMPONENT_VISIT_COUNT_FIELD = "cmp_visit_count";
    public static final String COMPONENT_SEARCH_COUNT_FIELD = "cmp_search_count";
    public static final String COMPONENT_WEIGHT_FIELD = "cmp_weight";
	public static final String COMPONENT_RESERVE_FIELD = "cmp_reserve";
	public static final String COMPONENT_SAMPLE_QTY_FIELD = "cmp_sample_qty";
	public static final String COMPONENT_ORIGINAL_QTY_FIELD = "cmp_original_qty";
	public static final String COMPONENT_INACTION_STOCK_QTY_FIELD = "cmp_inaction_stock_qty";
	public static final String COMPONENT_KI_ID_FIELD = "ki_id";
	public static final String COMPONENT_KI_NAME_UNTOKENIZED_FIELD = "ki_name_cn_untokenized";
	public static final String COMPONENT_KI_NAME_FIELD = "ki_name_cn";
	public static final String COMPONENT_KI_LEVEL_FIELD = "ki_level";
    public static final String COMPONENT_KI_VISIT_COUNT_FIELD = "ki_visit_count";
    public static final String COMPONENT_KI_SEARCH_COUNT_FIELD = "ki_search_count";
	public static final String COMPONENT_BR_ID_FIELD = "br_id";
	public static final String COMPONENT_BR_NAMECN_FIELD = "br_name_cn";
	public static final String COMPONENT_BR_NAMEEN_FIELD = "br_name_en";
	public static final String COMPONENT_BR_NAMECN_UNTOKENIZED_FIELD = "br_name_cn_untokenized";
	public static final String COMPONENT_BR_NAMEEN_UNTOKENIZED_FIELD = "br_name_en_untokenized";
	public static final String COMPONENT_BR_UUID_FIELD = "br_uuid";
    public static final String COMPONENT_BR_VISIT_COUNT_FIELD = "br_visit_count";
    public static final String COMPONENT_BR_SEARCH_COUNT_FIELD = "br_search_count";
    public static final String COMPONENT_BR_WEIGHT_FIELD = "br_weight";
	/**
	 * 创建器件属性的索引时，在属性id的前面添加该前缀作为Field的键
	 */
	public static final String COMPONENT_PROPERTY_PREFIX = "pr_";
	/**
	 * 另外创建的经过分词的属性值，添加后缀作为Field的键
	 */
	public static final String COMPONENT_PROPERTY_TOKENIZED_SUFFIX = "_tokenized";

	// 批次索引字段的key
	public static final String GOODS_GO_ID_FIELD = "go_id";
	public static final String GOODS_GO_RESERVE_FIELD = "go_reserve";
	public static final String GOODS_GO_STATUS_FIELD = "go_status";
	public static final String GOODS_GO_MINPRICERMB_FIELD = "go_minpricermb";
	public static final String GOODS_GO_MINPRICEUSD_FIELD = "go_minpriceusd";
    public static final String GOODS_GO_VISIT_COUNT_FIELD = "go_visit_count";
    public static final String GOODS_GO_MINDELIVERY_FIELD = "go_mindelivery";
    public static final String GOODS_GO_UPDATE_DATE_FIELD = "go_update_date";
	public static final String GOODS_CRNAME_FIELD = "cr_name";
	public static final String GOODS_ST_UUID_FIELD = "st_uuid";
	public static final String GOODS_ST_TYPE_FIELD = "st_type";
	public static final String GOODS_CMP_ID_FIELD = "cmp_id";
	public static final String GOODS_CMP_CODE_FIELD = "cmp_code";
	public static final String GOODS_CMP_DESCRIPTION_FIELD = "cmp_description";
    public static final String GOODS_CMP_VISIT_COUNT_FIELD = "cmp_visit_count";
    public static final String GOODS_CMP_SEARCH_COUNT_FIELD = "cmp_search_count";
    public static final String GOODS_CMP_WEIGHT_FIELD = "cmp_weight";
	public static final String GOODS_KI_ID_FIELD = "ki_id";
	public static final String GOODS_KI_NAME_CN_FIELD = "ki_name_cn";
	public static final String GOODS_KI_NAME_CN_UNTOKENIZED_FIELD = "ki_name_cn_untokenized";
	public static final String GOODS_KI_LEVEL_FIELD = "ki_level";
	public static final String GOODS_KI_ISLEAF_FIELD = "ki_isleaf";
    public static final String GOODS_KI_VISIT_COUNT_FIELD = "ki_visit_count";
    public static final String GOODS_KI_SEARCH_COUNT_FIELD = "ki_search_count";
	public static final String GOODS_BR_ID_FIELD = "br_id";
	public static final String GOODS_BR_NAME_CN_FIELD = "br_name_cn";
	public static final String GOODS_BR_NAME_EN_FIELD = "br_name_en";
	public static final String GOODS_BR_NAME_CN_UNTOKENIZED_FIELD = "br_name_cn_untokenized";
	public static final String GOODS_BR_NAME_EN_UNTOKENIZED_FIELD = "br_name_en_untokenized";
	public static final String GOODS_BR_UUID_FIELD = "br_uuid";
    public static final String GOODS_BR_VISIT_COUNT_FIELD = "br_visit_count";
    public static final String GOODS_BR_SEARCH_COUNT_FIELD = "br_search_count";
    public static final String GOODS_BR_WEIGHT_FIELD = "br_weight";
	public static final String GOODS_PR_ID_FIELD = "pr_id";
	public static final String GOODS_PR_PCMPCODE_FIELD = "pr_pcmpcode";
	public static final String GOODS_PR_PBRAND_EN_FIELD = "pr_pbranden";
	public static final String GOODS_PR_PBRAND_CN_FIELD = "pr_pbrand";
	public static final String GOODS_PR_PBRAND_EN_UNTOKENIZED_FIELD = "pr_pbranden_untokenized";
	public static final String GOODS_PR_PBRAND_CN_UNTOKENIZED_FIELD = "pr_pbrand_untokenized";
	public static final String GOODS_PR_PBRAND_EN_CN_STUUID_UNTOKENIZED_FIELD = "pr_pbranden_cn_stuuid_untokenized";
	public static final String GOODS_PR_KIND_FIELD = "pr_kind";
	public static final String GOODS_PR_KIND_UNTOKENIZED_FIELD = "pr_kind_untokenized";
	public static final String GOODS_KIND_STUUID_UNTOKENIZED_FIELD = "pr_kind_stuuid_untokenized";
	// 自动生成的字段，用于唯一区分批次索引
    public static final String GOODS_PRIMARY_KEY_FIELD = "primary_key";

    // PCB 批次索引字段的key
    public static final String PCB_GOODS_GO_ID_FIELD = "go_id";
    public static final String PCB_GOODS_GO_RESERVE_FIELD = "go_reserve";
    public static final String PCB_GOODS_GO_STATUS_FIELD = "go_status";
    public static final String PCB_GOODS_GO_MINPRICERMB_FIELD = "go_minpricermb";
    public static final String PCB_GOODS_GO_MINPRICEUSD_FIELD = "go_minpriceusd";
    public static final String PCB_GOODS_GO_VISIT_COUNT_FIELD = "go_visit_count";
    public static final String PCB_GOODS_GO_MINDELIVERY_FIELD = "go_mindelivery";
    public static final String PCB_GOODS_GO_UPDATE_DATE_FIELD = "go_update_date";
    public static final String PCB_GOODS_CRNAME_FIELD = "cr_name";
    public static final String PCB_GOODS_PCB_ID_FIELD = "pcb_id";
    public static final String PCB_GOODS_KI_ID_FIELD = "ki_id";
    public static final String PCB_GOODS_KI_NAME_CN_FIELD = "ki_name";
    public static final String PCB_GOODS_KI_NAME_CN_UNTOKENIZED_FIELD = "ki_name_cn_untokenized";
    public static final String PCB_GOODS_KI_LEVEL_FIELD = "ki_level";
    public static final String PCB_GOODS_KI_ISLEAF_FIELD = "ki_isleaf";
    public static final String PCB_GOODS_BR_ID_FIELD = "br_id";
    public static final String PCB_GOODS_BR_NAME_CN_FIELD = "br_name_cn";
    public static final String PCB_GOODS_BR_NAME_EN_FIELD = "br_name_en";
    public static final String PCB_GOODS_BR_NAME_CN_UNTOKENIZED_FIELD = "br_name_cn_untokenized";
    public static final String PCB_GOODS_BR_NAME_EN_UNTOKENIZED_FIELD = "br_name_en_untokenized";
    public static final String PCB_GOODS_BR_UUID_FIELD = "br_uuid";
    public static final String PCB_GOODS_PR_ID_FIELD = "pr_id";
    public static final String PCB_GOODS_PR_PCMPCODE_FIELD = "pr_pcmpcode";
    // 自动生成的字段，用于唯一区分批次索引
    public static final String PCB_GOODS_PRIMARY_KEY_FIELD = "primary_key";

	// 商城销售订单索引字段的key
	/**
	 * 对应销售单id（数据库id字段）
	 */
	public static final String ORDER_ID_FIELD = "or_id";
	/**
	 * 对应销售单号（数据库or_id字段），因易与id命名混淆，其他类、lucenne建索引时该字段难以区分，特以此命名
	 */
	public static final String ORDER_CODE_FIELD = "or_code";
	public static final String ORDER_BUYERUU_FIELD = "or_buyeruu";
	public static final String ORDER_BUYERNAME_FIELD = "or_buyername";
	public static final String ORDER_BUYERENUU_FIELD = "or_buyerenuu";
	public static final String ORDER_BUYERENNAME_FIELD = "or_buyerenname";
	public static final String ORDER_SELLERENUU_FIELD = "or_sellerenuu";
	public static final String ORDER_SELLERENNAME_FIELD = "or_sellerenname";
	public static final String ORDER_STATUS_FIELD = "or_status";
	public static final String ORDER_DETAILS_FIELD = "or_details";

	// 商城销售订单的发货单索引字段的key
	/**
	 * 对应商城销售订单的发货单id（数据库id字段）
	 */
	public static final String ORDER_INVOICE_ID_FIELD = "oi_id";
	/**
	 * 对应销售单发货单号（数据库in_id字段），因易与id命名混淆，其他类、lucenne建索引时该字段难以区分，特以此命名
	 */
	public static final String ORDER_INVOICE_CODE_FIELD = "oi_code";
	public static final String ORDER_INVOICE_BUYERUU_FIELD = "oi_buyeruu";
	public static final String ORDER_INVOICE_BUYERNAME_FIELD = "oi_buyername";
	public static final String ORDER_INVOICE_BUYERENUU_FIELD = "oi_buyerenuu";
	public static final String ORDER_INVOICE_BUYERENNAME_FIELD = "oi_buyerenname";
	public static final String ORDER_INVOICE_STATUS_FIELD = "oi_status";
	public static final String ORDER_INVOICE_DETAILS_FIELD = "oi_details";

	// 商城采购订单索引字段的key
	/**
	 * 对应采购单id（数据库id字段）
	 */
	public static final String PURCHASE_ID_FIELD = "pu_id";
	/**
	 * 对应采购单号（数据库pu_id字段），因易与id命名混淆，其他类、lucenne建索引时该字段难以区分，特以此命名
	 */
	public static final String PURCHASE_CODE_FIELD = "pu_code";
	public static final String PURCHASE_SELLERENUU_FIELD = "pu_sellerenuu";
	public static final String PURCHASE_SELLERENNAME_FIELD = "pu_sellerenname";
	public static final String PURCHASE_STATUS_FIELD = "pu_status";
	public static final String PURCHASE_DETAILS_FIELD = "pu_details";

	// 商城采购订单的发货单索引字段的key
	/**
	 * 对应商城采购订单的发货单id（数据库id字段）
	 */
	public static final String PURCHASE_INVOICE_ID_FIELD = "pi_id";
	/**
	 * 对应采购单发货单号（数据库in_id字段），因易与id命名混淆，其他类、lucenne建索引时该字段难以区分，特以此命名
	 */
	public static final String PURCHASE_INVOICE_CODE_FIELD = "pi_code";
	public static final String PURCHASE_INVOICE_SELLERENUU_FIELD = "pi_sellerenuu";
	public static final String PURCHASE_INVOICE_SELLERENNAME_FIELD = "pi_sellerenname";
	public static final String PURCHASE_INVOICE_STATUS_FIELD = "pi_status";
	public static final String PURCHASE_INVOICE_DETAILS_FIELD = "pi_details";

	public static final String CREATETIME_FIELD = "createtime";

	/**
	 * 物料索引字段
	 */
	public static final String PRODUCT_PRIVATE_ID_FIELD = "pr_id";
	// enUU
	public static final String PRODUCT_PRIVATE_ENUU_FIELD = "pr_enuu";
	// 1标准  0非标准
	public static final String PRODUCT_PRIVATE_STANDARD_FIELD = "pr_standard";
	// 1可用  0 不可用
	public static final String PRODUCT_PRIVATE_B2CENABLED_FIELD = "pr_b2cenabled";
	// 1可卖  0 不可
	public static final String PRODUCT_PRIVATE_ISSALE_FIELD = "pr_issale";
	// 1可买  0 不可
	public static final String PRODUCT_PRIVATE_ISPURCHASE_FIELD = "pr_ispurchase";
	// 1可公开展示  0 不可
	public static final String PRODUCT_PRIVATE_ISSHOW_FIELD = "pr_isshow";
	// 1可公开销售  0 不可
	public static final String PRODUCT_PRIVATE_ISPUBSALE_FIELD = "pr_ispubsale";

    /**
     * 非标字段
     */
    // 名称
    public static final String PRODUCT_PRIVATE_TITLE_FIELD = "pr_title";
    // 型号
	public static final String PRODUCT_PRIVATE_CMPCODE_FIELD = "pr_cmpcode";
	// 编号
	public static final String PRODUCT_PRIVATE_CODE_FIELD = "pr_code";
	// 品牌
	public static final String PRODUCT_PRIVATE_BRAND_FIELD = "pr_brand";
    /**
     * 标准字段
     */
	// 品牌英文名
	public static final String PRODUCT_PRIVATE_PBRAND_EN_FIELD = "pr_pbranden";
	// 品牌中文名
	public static final String PRODUCT_PRIVATE_PBRAND_CN_FIELD = "pr_pbrand";
	// 品牌+enuu
	public static final String PRODUCT_PRIVATE_PBRAND_ENUU_FIELD = "pr_pbrand_enuu";
    // 类目
    public static final String PRODUCT_PRIVATE_KIND_FIELD = "pr_kind";
	// 规格
	public static final String PRODUCT_PRIVATE_SPEC_FIELD = "pr_spec";
	// 类目+enuu
	public static final String PRODUCT_PRIVATE_KIND_ENUU_FIELD = "pr_kind_enuu";
    // 标准型号
    public static final String PRODUCT_PRIVATE_PCMPCODE_FIELD = "pr_pcmpcode";
    // 标准英文品牌
    public static final String PRODUCT_PRIVATE_PBRANDEN_FIELD = "pr_pbranden";

	// 个人物料表索引字段
	// ID
	public static final String PRODUCT_USER_ID_FIELD = "pu_id";
	// 物料ID
	public static final String PRODUCT_USER_PRID_FIELD = "pu_prid";
	// 用户uu
	public static final String PRODUCT_USER_USERUU_FIELD = "pu_useruu";
	// 企业uu
	public static final String PRODUCT_USER_ENUU_FIELD = "pu_enuu";
	// 物料id
	public static final String PRODUCT_USER_PRODUCT_ID_FIELD = "pr_id";
	// 用户上传物料类目
	public static final String PRODUCT_USER_PRODUCT_TITLE_FIELD = "pr_title";
	// 用户上传物料规格
	public static final String PRODUCT_USER_PRODUCT_SPEC_FIELD = "pr_spec";
	// 用户上传物料型号
	public static final String PRODUCT_USER_PRODUCT_CMPCODE_FIELD = "pr_cmpcode";
	// 物料编号
	public static final String PRODUCT_USER_PRODUCT_CODE_FIELD = "pr_code";
	// 用户上传品牌
	public static final String PRODUCT_USER_PRODUCT_BRAND_FIELD = "pr_brand";
	// 类目
	public static final String PRODUCT_USER_PRODUCT_KIND_FIELD = "pr_kind";
	// 标准型号
	public static final String PRODUCT_USER_PRODUCT_PCMPCODE_FIELD = "pr_pcmpcode";
	// 标准品牌英文名
	public static final String PRODUCT_USER_PRODUCT_PBRAND_EN_FIELD = "pr_pbranden";
	// 标准品牌中文名
	public static final String PRODUCT_USER_PRODUCT_PBRAND_CN_FIELD = "pr_pbrand";
	// 是否标准
	public static final String PRODUCT_USER_PRODUCT_STANDARD_FIELD = "standard";
	// 是否可用
	public static final String PRODUCT_USER_PRODUCT_B2CENABLED_FIELD = "pr_b2cenabled";
	// 是否可卖
	public static final String PRODUCT_USER_PRODUCT_ISSALE_FIELD = "pr_issale";
	// 是否可买
	public static final String PRODUCT_USER_PRODUCT_ISPURCHASE_FIELD = "pr_ispurchase";
	// 是否可公开展示
	public static final String PRODUCT_USER_PRODUCT_ISSHOW_FIELD = "pr_isshow";
	// 是否可公开采购
	public static final String PRODUCT_USER_PRODUCT_ISPUBSALE_FIELD = "pr_ispubsale";
}
