package com.uas.search.console.b2b.service;

import com.uas.search.b2b.service.SearchService.Table_name;
import com.uas.search.console.b2b.jms.ParsedQueueMessage;
import com.uas.search.console.b2b.support.DownloadHelper;

import java.io.IOException;
import java.util.List;

/**
 * 索引处理
 *
 * @author sunyj
 * @since 2016年11月10日 上午9:55:00
 */
public interface IndexService {

	/**
	 * 创建指定表的索引
	 *
	 * @param tableNames
	 *            可为空，指定的表，默认创建所有表的索引
	 * @param fromFiles
	 *            可为空，索引数据是否来自文件，默认来自文件
	 * @param ifStartListener
	 *            可为空，是否开启实时更新，默认开启
	 * @return 创建的索引花费总时间 ms
	 */
	public Long createIndexes(List<Table_name> tableNames, Boolean fromFiles, Boolean ifStartListener) throws IOException, InterruptedException;

	/**
	 * 下载指定表的数据至本地文件中，以供建索引用
	 *
	 * @param tableNames
	 *            可为空，指定的表，默认下载所有表的数据
	 * @return 花费总时间 ms
	 */
	public Long downloadData(List<Table_name> tableNames);

    /**
     * 下载指定表的数据至本地文件中，以供建索引用
     *
     * @param tableName
     *            指定的表
     * @param startFileIndex
     *            可为空，从第startFileIndex个文件开始下载（只指定一个表时才起作用）
     * @return 花费总时间 ms
     */
    public Long downloadData(Table_name tableName, Integer startFileIndex);

	/**
	 * 多线程下载指定表的数据至本地文件中，以供建索引用
	 *  @param tableNames     可为空，指定的表，默认下载所有表的数据
	 * @param threads        线程数量，默认为 1
     * @param validateResult 下载完成后，是否对结果进行校验
     * @return 下载的数据条数
     */
	public long multiDownloadData(List<Table_name> tableNames, Integer threads, DownloadHelper.ValidateResult validateResult);

	/**
	 * 多线程下载指定表的数据至本地文件中，以供建索引用
	 *  @param tableName      指定的表
	 * @param threads        线程数量，默认为 1
     * @param startFileIndex 开始的文件，默认为 1
     * @param endFileIndex   结束的文件，默认为 1024 * 1024 * 1024
     * @param validateResult 下载完成后，是否对结果进行校验
     * @return 下载的数据条数
     */
	public long multiDownloadData(Table_name tableName, Integer threads, Integer startFileIndex, Integer endFileIndex, DownloadHelper.ValidateResult validateResult);

	/**
	 * 将新对象添加在lucene索引中
	 *
	 * @param <T>
	 *
	 * @param obj
	 */
	public <T> T save(T obj);

	/**
	 * 根据新对象对lucene索引进行更新
	 *
	 * @param <T>
	 *
	 * @param obj
	 */
	public <T> T update(T obj);

	/**
	 * 将对象从lucene索引中删除
	 *
	 * @param <T>
	 *
	 * @param obj
	 */
	public <T> T delete(T obj);

	/**
	 * 根据自队列消息解析出来的对象，对lucene索引进行添加、更新或删除操作
	 *
	 * @param parsedQueueMessage
	 *            自队列消息解析出来的对象
	 * @return 维护的对象
	 */
	public List<Object> maintainIndexes(ParsedQueueMessage parsedQueueMessage);

    /**
     * 根据实体类型名维护出问题的表的索引
     *
     * @param tableName  需维护的实体类型名
     * @param dataId     需维护的id
     * @param methodType 需对索引做何种更改
     * @param data       数据
     * @return 维护的对象
     */
    List<Object> maintainIndexesById(String tableName, Long dataId, String methodType, String data);

	/**
	 * 根据实体类型名维护出问题的表的索引
	 *
	 * @param tableName
	 *            需维护的实体类型名
	 * @param data
	 *            需维护的数据，JSONArray格式
	 * @param methodType
	 *            需对索引做何种更改
	 * @return 维护的对象
	 */
    List<Object> maintainIndexesByData(String tableName, String data, String methodType);
}
